# Test Coverage Report: excluded packages and modules

Generated: Thu 2013-12-19 21:13 GMT

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- ftp_deploy.__init__
- ftp_deploy.admin
- ftp_deploy.conf
- ftp_deploy.migrations
- ftp_deploy.models.__init__
- ftp_deploy.server.__init__
- ftp_deploy.server.forms.__init__
- ftp_deploy.server.models
- ftp_deploy.server.templatetags.__init__
- ftp_deploy.server.urls
- ftp_deploy.server.views.__init__
- ftp_deploy.tests
- ftp_deploy.urls
- ftp_deploy.utils.__init__

Back to index.